import { API as ParentAPI } from '../../../bridge';
import type { Zone as ScwZone, WaitForOptions } from '../../../bridge';
import type { AttachFlexibleIPRequest, AttachFlexibleIPsResponse, CreateFlexibleIPRequest, DeleteFlexibleIPRequest, DeleteMACAddrRequest, DetachFlexibleIPRequest, DetachFlexibleIPsResponse, DuplicateMACAddrRequest, FlexibleIP, GenerateMACAddrRequest, GetFlexibleIPRequest, ListFlexibleIPsRequest, ListFlexibleIPsResponse, MoveMACAddrRequest, UpdateFlexibleIPRequest } from './types.gen';
/**
 * Elastic Metal - Flexible IP API.
 *
 * This API allows you to manage your Elastic Metal servers' flexible public IP
 * addresses.
 */
export declare class API extends ParentAPI {
    /** Lists the available zones of the API. */
    static readonly LOCALITIES: ScwZone[];
    /**
     * Create a new flexible IP. Generate a new flexible IP within a given zone,
     * specifying its configuration including Project ID and description.
     *
     * @param request - The request {@link CreateFlexibleIPRequest}
     * @returns A Promise of FlexibleIP
     */
    createFlexibleIP: (request: Readonly<CreateFlexibleIPRequest>) => Promise<FlexibleIP>;
    /**
     * Get an existing flexible IP. Retrieve information about an existing
     * flexible IP, specified by its ID and zone. Its full details, including
     * Project ID, description and status, are returned in the response object.
     *
     * @param request - The request {@link GetFlexibleIPRequest}
     * @returns A Promise of FlexibleIP
     */
    getFlexibleIP: (request: Readonly<GetFlexibleIPRequest>) => Promise<FlexibleIP>;
    /**
     * Waits for {@link FlexibleIP} to be in a final state.
     *
     * @param request - The request {@link GetFlexibleIPRequest}
     * @param options - The waiting options
     * @returns A Promise of FlexibleIP
     */
    waitForFlexibleIP: (request: Readonly<GetFlexibleIPRequest>, options?: Readonly<WaitForOptions<FlexibleIP>>) => Promise<FlexibleIP>;
    protected pageOfListFlexibleIPs: (request?: Readonly<ListFlexibleIPsRequest>) => Promise<ListFlexibleIPsResponse>;
    /**
     * List flexible IPs. List all flexible IPs within a given zone.
     *
     * @param request - The request {@link ListFlexibleIPsRequest}
     * @returns A Promise of ListFlexibleIPsResponse
     */
    listFlexibleIPs: (request?: Readonly<ListFlexibleIPsRequest>) => Promise<ListFlexibleIPsResponse> & {
        all: () => Promise<FlexibleIP[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<FlexibleIP[], void, void>;
    };
    /**
     * Update an existing flexible IP. Update the parameters of an existing
     * flexible IP, specified by its ID and zone. These parameters include tags
     * and description.
     *
     * @param request - The request {@link UpdateFlexibleIPRequest}
     * @returns A Promise of FlexibleIP
     */
    updateFlexibleIP: (request: Readonly<UpdateFlexibleIPRequest>) => Promise<FlexibleIP>;
    /**
     * Delete an existing flexible IP. Delete an existing flexible IP, specified
     * by its ID and zone. Note that deleting a flexible IP is permanent and
     * cannot be undone.
     *
     * @param request - The request {@link DeleteFlexibleIPRequest}
     */
    deleteFlexibleIP: (request: Readonly<DeleteFlexibleIPRequest>) => Promise<void>;
    /**
     * Attach an existing flexible IP to a server. Attach an existing flexible IP
     * to a specified Elastic Metal server.
     *
     * @param request - The request {@link AttachFlexibleIPRequest}
     * @returns A Promise of AttachFlexibleIPsResponse
     */
    attachFlexibleIP: (request: Readonly<AttachFlexibleIPRequest>) => Promise<AttachFlexibleIPsResponse>;
    /**
     * Detach an existing flexible IP from a server. Detach an existing flexible
     * IP from a specified Elastic Metal server.
     *
     * @param request - The request {@link DetachFlexibleIPRequest}
     * @returns A Promise of DetachFlexibleIPsResponse
     */
    detachFlexibleIP: (request: Readonly<DetachFlexibleIPRequest>) => Promise<DetachFlexibleIPsResponse>;
    /**
     * Generate a virtual MAC address on an existing flexible IP. Generate a
     * virtual MAC (Media Access Control) address on an existing flexible IP.
     *
     * @param request - The request {@link GenerateMACAddrRequest}
     * @returns A Promise of FlexibleIP
     */
    generateMACAddr: (request: Readonly<GenerateMACAddrRequest>) => Promise<FlexibleIP>;
    /**
     * Duplicate a virtual MAC address to another flexible IP. Duplicate a virtual
     * MAC address from a given flexible IP to another flexible IP attached to the
     * same server.
     *
     * @param request - The request {@link DuplicateMACAddrRequest}
     * @returns A Promise of FlexibleIP
     */
    duplicateMACAddr: (request: Readonly<DuplicateMACAddrRequest>) => Promise<FlexibleIP>;
    /**
     * Relocate an existing virtual MAC address to a different flexible IP.
     * Relocate a virtual MAC (Media Access Control) address from an existing
     * flexible IP to a different flexible IP.
     *
     * @param request - The request {@link MoveMACAddrRequest}
     * @returns A Promise of FlexibleIP
     */
    moveMACAddr: (request: Readonly<MoveMACAddrRequest>) => Promise<FlexibleIP>;
    /**
     * Detach a given virtual MAC address from an existing flexible IP. Detach a
     * given MAC (Media Access Control) address from an existing flexible IP.
     *
     * @param request - The request {@link DeleteMACAddrRequest}
     */
    deleteMACAddr: (request: Readonly<DeleteMACAddrRequest>) => Promise<void>;
}
