import { tryAtIntervals, createExponentialBackoffStrategy } from "../../../internal/async/interval-retrier.js";
import { API, ZonedAPI } from "./api.gen.js";
import { PRIVATE_NETWORK_TRANSIENT_STATUSES, LB_TRANSIENT_STATUSES, INSTANCE_TRANSIENT_STATUSES } from "./content.gen.js";
class LbV1UtilsAPI extends API {
  /**
   * Waits for all private networks of a load balancer to be in a final state.
   *
   * @param request - The request {@link WaitForLbPrivateNetworksRequest}
   * @param options - The waiting options
   * @returns A Promise of ListLbPrivateNetworksResponse
   */
  waitForLbPrivateNetworks = (request, options) => tryAtIntervals(
    async () => {
      const value = await this.listLbPrivateNetworks({
        lbId: request.lbId,
        region: request.region
      }).all().then((list) => ({
        privateNetwork: list,
        totalCount: list.length
      }));
      return {
        done: value.privateNetwork.find(
          (elt) => PRIVATE_NETWORK_TRANSIENT_STATUSES.includes(elt.status)
        ) === void 0,
        value
      };
    },
    createExponentialBackoffStrategy(
      options?.minDelay ?? 1,
      options?.maxDelay ?? 30
    ),
    options?.timeout
  );
  /**
   * Waits for all instances of a load balancer to be in a final state.
   *
   * @param request - The request {@link GetLbRequest}
   * @param options - The waiting options
   * @returns A Promise of Lb
   */
  waitForLbInstances = (request, options) => tryAtIntervals(
    async () => {
      const value = await this.getLb(request);
      return {
        done: !LB_TRANSIENT_STATUSES.includes(value.status) && value.instances.find(
          (elt) => INSTANCE_TRANSIENT_STATUSES.includes(elt.status)
        ) === void 0,
        value
      };
    },
    createExponentialBackoffStrategy(
      options?.minDelay ?? 1,
      options?.maxDelay ?? 30
    ),
    options?.timeout
  );
}
class LbZonedV1UtilsAPI extends ZonedAPI {
  /**
   * Waits for all private networks of a (zoned) load balancer to be in a final
   * state.
   *
   * @param request - The request {@link ZonedWaitForLbPrivateNetworksRequest}
   * @param options - The waiting options
   * @returns A Promise of ListLbPrivateNetworksResponse
   */
  waitForLbPrivateNetworks = (request, options) => tryAtIntervals(
    async () => {
      const value = await this.listLbPrivateNetworks({
        lbId: request.lbId,
        zone: request.zone
      }).all().then((list) => ({
        privateNetwork: list,
        totalCount: list.length
      }));
      return {
        done: value.privateNetwork.find(
          (elt) => PRIVATE_NETWORK_TRANSIENT_STATUSES.includes(elt.status)
        ) === void 0,
        value
      };
    },
    createExponentialBackoffStrategy(
      options?.minDelay ?? 1,
      options?.maxDelay ?? 30
    ),
    options?.timeout
  );
  /**
   * Waits for all instances of a (zoned) load balancer to be in a final state.
   *
   * @param request - The request {@link GetLbRequest}
   * @param options - The waiting options
   * @returns A Promise of Lb
   */
  waitForLbInstances = (request, options) => tryAtIntervals(
    async () => {
      const value = await this.getLb(request);
      return {
        done: !LB_TRANSIENT_STATUSES.includes(value.status) && value.instances.find(
          (elt) => INSTANCE_TRANSIENT_STATUSES.includes(elt.status)
        ) === void 0,
        value
      };
    },
    createExponentialBackoffStrategy(
      options?.minDelay ?? 1,
      options?.maxDelay ?? 30
    ),
    options?.timeout
  );
}
export {
  LbV1UtilsAPI,
  LbZonedV1UtilsAPI
};
